# clang.cindex の python module

pycindex では `setup.py` で llvm-13.0 のスクリプトをダウンロードします。

<https://github.com/llvm/llvm-project/tree/llvmorg-13.0.0/clang/bindings/python/clang>

## pypi

非公式のパッケージ

* [clang 11.0](https://pypi.org/project/clang/)
* [libclang 12.0.0](https://pypi.org/project/libclang/)

使用する `libclang.dll` のバージョンと一致するか確認した方がよいかも。
